from pyrfuniverse.attributes.base_attr import BaseAttr
from pyrfuniverse.attributes.camera_attr import CameraAttr
from pyrfuniverse.attributes.gameobject_attr import GameObjectAttr
from pyrfuniverse.attributes.light_attr import LightAttr
from pyrfuniverse.attributes.collider_attr import ColliderAttr
from pyrfuniverse.attributes.controller_attr import ControllerAttr
from pyrfuniverse.attributes.rigidbody_attr import RigidbodyAttr
from pyrfuniverse.attributes.cloth_attr import ClothAttr
from pyrfuniverse.attributes.pointcloud_attr import PointCloudAttr
from pyrfuniverse.attributes.custom_attr import CustomAttr

attrs = {
"BaseAttr": BaseAttr,
"CameraAttr": CameraAttr,
"GameObjectAttr": GameObjectAttr,
"LightAttr": LightAttr,
"ColliderAttr": ColliderAttr,
"ControllerAttr": ControllerAttr,
"RigidbodyAttr": RigidbodyAttr,
"ClothAttr": ClothAttr,
"PointCloudAttr": PointCloudAttr,
"CustomAttr": CustomAttr
}
